@@ -14,12 +14,22 @@
 
 import acos_client.v21.base as base
 
-from persistence import CookiePersistence
-from persistence import SourceIpPersistence
+from acos_client.v21.slb.template.persistence import CookiePersistence
+from acos_client.v21.slb.template.persistence import SourceIpPersistence
+from acos_client.v21.slb.template.template_ssl import ClientSSL
+from acos_client.v21.slb.template.template_ssl import ServerSSL
 
 
 class Template(base.BaseV21):
 
+    @property
+    def client_ssl(self):
+        return ClientSSL(self.client)
+
+    @property
+    def server_ssl(self):
+        return ServerSSL(self.client)
+
     @property
     def cookie_persistence(self):
         return CookiePersistence(self.client)
