@@ -20,13 +20,18 @@ from acos_client.v30 import base
 
 class Action(base.BaseV30):
 
-    def write_memory(self, partition="all", destination="primary", **kwargs):
+    def write_memory(self, partition="all", destination=None, specified_partition=None, **kwargs):
         payload = {
             "memory": {
                 "destination": destination,
                 "partition": partition
             }
         }
+
+        if specified_partition:
+            del payload["memory"]["destination"]
+            payload["memory"]["specified-partition"] = specified_partition
+
         try:
             try:
                 self._post("/write/memory/", payload, **kwargs)
@@ -37,7 +42,7 @@ class Action(base.BaseV30):
             # If the retry loop missed this, catch it next time.
             pass
 
-    def activate_and_write(self, partition="all", destination="primary", **kwargs):
+    def activate_and_write(self, partition="all", destination=None, **kwargs):
         self.write_memory(partition, destination)
 
     def clideploy(self, commandlist, **kwargs):
@@ -84,7 +89,7 @@ class Action(base.BaseV30):
 
     def set_vcs_para(self, floating_ip, floating_ip_mask):
         data = {"vcs-para": {"floating-ip-cfg": [{"floating-ip": floating_ip,
-                "floating-ip-mask": floating_ip_mask}]}}
+                "floating-ip-mask": floating_ip_mask}], "forever": 1}}
         url = "/vcs/vcs-para"
         self._post(url, data)
 
@@ -106,3 +111,49 @@ class Action(base.BaseV30):
             return True
         else:
             return False
+
+    def get_vcs_summary_oper(self):
+        url = "/vcs/vcs-summary/oper"
+        return self._get(url)
+
+    def get_thunder_up_time(self):
+        url = "/miscellenious-alb/oper"
+        return self._get(url)
+
+    def probe_network_devices(self):
+        url = "/system/probe-network-devices"
+        self._post(url)
+
+    def get_acos_version(self):
+        url = "/version/oper"
+        return self._get(url)
+
+    def reload_reboot_for_interface_attachment(self, acos_version=None):
+        if not acos_version:
+            version_summary = self.get_acos_version()
+            acos_version = version_summary['version']['oper']['sw-version'].split(',')[0]
+
+        major = acos_version.split('.')[0]
+        minor = acos_version.split('.')[1]
+        patch = acos_version.split('.')[2]
+
+        if major >= 5 and minor >= 2 and patch >= 0:
+            self.probe_network_devices()
+            self.reload()
+        else:
+            self.reboot()
+
+    def reload_reboot_for_interface_detachment(self, acos_version=None):
+        if not acos_version:
+            version_summary = self.get_acos_version()
+            acos_version = version_summary['version']['oper']['sw-version'].split(',')[0]
+
+        major = acos_version.split('.')[0]
+        minor = acos_version.split('.')[1]
+        patch = acos_version.split('.')[2]
+
+        if major >= 5 and minor >= 2 and patch >= 1:
+            self.probe_network_devices()
+            self.reload()
+        else:
+            self.reboot()
